<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Http\Services\LdapConnectService;
use App\Models\Role;
use App\Models\User;
use App\Providers\RouteServiceProvider;
use Illuminate\Foundation\Auth\AuthenticatesUsers;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Validation\ValidationException;

class LoginController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Login Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles authenticating users for the application and
    | redirecting them to your home screen. The controller uses a trait
    | to conveniently provide its functionality to your applications.
    |
    */

    use AuthenticatesUsers;

    /**
     * Where to redirect users after login.
     *
     * @var string
     */
    protected $redirectTo = RouteServiceProvider::HOME;

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest')->except('logout');
    }

    /**
     * Handle a login request to the application.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Http\Response|\Illuminate\Http\JsonResponse
     *
     * @throws \Illuminate\Validation\ValidationException
     */

    public function login(Request $request)
    {
        $request->validate([
         "login" => "string|required|min:2",
         "password" => "string|required|min:2"
        ]);

        if (method_exists($this, 'hasTooManyLoginAttempts') &&
        $this->hasTooManyLoginAttempts($request)) {
            $this->fireLockoutEvent($request);
            return $this->sendLockoutResponse($request);
        }

        $user = User::where('username', $request->login)->orWhere("email", $request->login)->first();
        $ldap = new LdapConnectService();
        $bind = $ldap->bind($request->login, $request->password);


        if(!$user) {
            if (gettype($bind) != "string") {

                $ldap->createOrUpdateLogin(
                    '\App\Models\User',
                    [
                        'username' => $request->login,
                    'has_ad' => now(),
                    'password' => null,
                    'email' => $request->login."@".config('ldap.mail_domain'),
                    'name' => implode(" ", explode(".", $request->login)),
                    'role_id' => Role::where('role', 'Admin')->first()->id
                ]
                );

                return $this->sendLoginResponse($request);
            }
            $this->incrementLoginAttempts($request);
            return $this->sendFailedLoginResponse($request);
        }
        if($user->has_ad && $user->username != null) {
            if(str_contains($request->login, "@")) {
                $this->incrementLoginAttempts($request);
                return $this->sendFailedLoginResponse($request);

            }

            if (gettype($bind) != "string") {
                Auth::login($user);
                return $this->sendLoginResponse($request);
            }
        }


        $request->merge(['email' => $request->login]);
        if ($this->attemptLogin($request)) {
            if ($request->hasSession()) {
                $request->session()->put('auth.password_confirmed_at', time());
            }
            return $this->sendLoginResponse($request);
        }

        $this->incrementLoginAttempts($request);
        return $this->sendFailedLoginResponse($request);

    }

    /**
     * Get the failed login response instance.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Symfony\Component\HttpFoundation\Response
     *
     * @throws \Illuminate\Validation\ValidationException
     */
    protected function sendFailedLoginResponse(Request $request)
    {
        throw ValidationException::withMessages([
            "login" => [trans('auth.failed')],
        ]);
    }
}
