<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\CadastroBem;
use Illuminate\Support\Facades\Http;
use Nette\Utils\Json;
use stdClass;

class BarcodeController extends Controller
{
    // Método para exibir a view de leitura do código de barras
    public function showBarcodeReader()
    {
        return view('pages.consumo-teste.leitor-html5-qrcode');
    }

    // Método para buscar o patrimônio pelo código de barras
    public function buscarCodigo(Request $request)
    {
        $codigo = $request->input('code');

        // Remove aspas
        $codigoTratado = str_replace('"', '', $codigo);

        // Encontra todos os trechos com 12 caracteres numéricos
        preg_match_all('/\b\d{12}\b/', $codigoTratado, $output_array);

        // Remove os zeros de cada número, adiciona "17" antes dos primeiros 5 números e remove o último dígito
        $items = array_map(function ($number) {
            // Remover os zeros
            $number = ltrim($number, '0');

            $number = '17' . substr($number, 0, 5) . substr($number, 5);
            // Remove o último número
            return substr($number, 0, -1);
        }, $output_array[0]);


        $codigoTratado = $items[0] ?? null;

        // Requisição para o Sispat
        $http = Http::sispat()->get('patrimonio.php', ["tombamento" => $codigoTratado]);

        // Tratamento do retorno
        $body = preg_replace('/([{,])(\s*)([A-Za-z0-9_\-]+?)\s*:/', '$1"$3":', $http->body());
        $body = str_replace("\n", "", str_replace("\r", "", $body));
        $body = str_replace('﻿', '', $body);


        if($body == "Not found." || empty($body)) {
            return redirect()->route('leitor-codigo')->with('error', 'Patrimônio não encontrado.');
        }


        $response = explode("|", trim($body));


        $patrimonio = new stdClass();
        $patrimonio->num_tombamento_cadastro_bem = $codigoTratado;
        $patrimonio->txt_desc_bem_cadastro_bem = $response[0] ?? null;
        $patrimonio->txt_desc_setor = $response[1] ?? null;
        $patrimonio->txt_sigla_setor = $response[2] ?? null;

        return view('pages.consumo-teste.resultado', compact('patrimonio'));

    }

    // Método para processar o código de barras lido
    public function storeBarcode(Request $request)
    {
        $barcode = $request->input('code');
        // Apenas retorna o código de barras recebido para fins de teste
        return response()->json(['code' => $barcode]);
    }

    public function showBarcodeResult($code)
    {
        return view('pages.consumo-teste.leitor-visualizar', ['code' => $code]);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
