<?php

namespace App\Http\Controllers;

use App\Helpers;
use App\Http\Requests\Inventario\CreateRequest;
use App\Models\CadastroBem;
use App\Models\Inventario;
use App\Models\Setor;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Http;
use stdClass;

class InventarioController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {

        $inventarios = Inventario::orderBy('id', 'desc')->paginate(20);

        return view('pages.inventarios.index', compact('inventarios'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $setores = Setor::all();

        return view('pages.inventarios.create', compact('setores'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(CreateRequest $request)
    {
        $request->validated();
        $inventario = Inventario::create([
            'setor_id' => $request->setor
        ]);

        return redirect()->route('inventarios.edit', ["inventario" => $inventario->id]);
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Inventario  $inventario
     * @return \Illuminate\Http\Response
     */
    public function show(Inventario $inventario)
    {
        return view('pages.inventarios.show', compact('inventario'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Inventario  $inventario
     * @return \Illuminate\Http\Response
     */
    public function edit(Inventario $inventario)
    {
        return view('pages.inventarios.edit', compact('inventario'));
    }

    public function ajaxInsert(Request $request)
    {
        $request->validate([
            'tombamento' => 'required|string|max:14',
            'inventario_id' => 'required|exists:inventarios,id'
        ]);

        $codigo = Helpers::trata_tombamento($request->tombamento);

        if(!$codigo) {
            return response()->json(['error' => 'Código de barras inválido'], 400);
        }

        // Requisição para o Sispat
        $http = Http::sispat()->get('patrimonio.php', ["tombamento" => $codigo]);

        $body = Helpers::clean_body($http->body());

        if($body == "Not found." || empty($body)) {
            return response()->json(['error' => 'Patrimônio não encontrado'], 404);
        }

        $response = explode("|", trim($body));
        $setor = Setor::search(['descricao' => $response[1], 'sigla' => $response[2]])->first();

        if(!$setor) {
            return response()->json(['error' => 'Setor '. $response[2] .' não encontrado, antes de continuar, favor atualizar os setores'], 404);
        }
        if(CadastroBem::where(['tombamento' => $codigo, 'inventario_id' => $request->inventario_id])->first()) {
            return response()->json(['error' => 'Item já cadastrado'], 400);
        };

        $bem = CadastroBem::create([
            "tombamento" => $codigo,
            "descricao" => $response[0],
            "setor_id" => $setor->id,
            "inventario_id" => $request->inventario_id
        ]);
        $bem->setor = $setor;

        $inventario = Inventario::find($request->inventario_id);
        $inventario->update(["updated_at" => now()]);

        return response()->json($bem);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Inventario  $inventario
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Inventario $inventario)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Inventario  $inventario
     * @return \Illuminate\Http\Response
     */
    public function destroy(Inventario $inventario)
    {
        $inventario->delete();
        return redirect()->route('inventarios.index')->with(["message" => "Inventário deletado com sucesso!"]);
    }


    /**
     * Print the specified inventario.
     * @param string $id
     */
    public function print(string $id)
    {
        $inventario = Inventario::findOrFail($id);
        return view('pages.inventarios.print', compact('inventario'));
    }
}
