<?php

use App\Http\Controllers\Auth\ForgotPasswordController;
use App\Http\Controllers\Auth\LoginController;
use App\Http\Controllers\Auth\ResetPasswordController;
use App\Http\Controllers\BarcodeController;
use App\Http\Controllers\CadastroBemController;
use App\Http\Controllers\ConsumoTesteController;
use App\Http\Controllers\InventarioController;
use App\Http\Controllers\SetorController;
use App\Http\Controllers\UpdateUserAd;
use App\Http\Controllers\UserController;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('/', function () {
    return view('auth.login');
});

Route::group(['middleware' => ['auth']], function () {
    Route::get('/update_ad', [UpdateUserAd::class, 'edit'])->name('edit-user-ad');
    Route::put('/update_ad', [UpdateUserAd::class, 'update'])->name('update-user-ad');
}) ;

Route::group(['middleware' => ['auth', 'ensure.ad']], function () {

    // Auth::routes();



    Route::get('/home', [App\Http\Controllers\HomeController::class, 'index'])->name('home');

    // Route::resource substitui a necessidade de criar rotas para cada método do controller
    Route::resource("inventarios", InventarioController::class)->name('*', 'inventarios');
    Route::get('setores', [SetorController::class, 'index'])->name('setores.index');
    Route::get('setores/update', [SetorController::class, 'update'])->name('setores.update');
    Route::post('inventarios/ajax_insert', [InventarioController::class, 'ajaxInsert'])->name('inventarios.ajax_insert');
    Route::post('cadastroBem/delete', [CadastroBemController::class, 'destroy'])->name('cadastroBem.destroy');
    Route::get('inventario/print/{inventario}', [InventarioController::class, 'print'])->name('inventarios.print');

    // Route::prefix('inventarios')->group(function () {
    //     Route::get('/', [InventarioController::class, 'index'])->name('inventarios.index');
    //     Route::get('/create', [InventarioController::class, 'create'])->name('inventarios.create');
    //     Route::post('/store', [InventarioController::class, 'store'])->name('inventarios.store');
    //     Route::get('/edit/{id}', [InventarioController::class, 'edit'])->name('inventarios.edit');
    //     Route::post('/update/{id}', [InventarioController::class, 'update'])->name('inventarios.update');
    //     Route::get('/show/{id}', [InventarioController::class, 'show'])->name('inventarios.show');
    //     Route::delete('/delete', [InventarioController::class, 'delete'])->name('inventarios.delete');

    // });


    Route::prefix('consumo-teste')->group(function () {
        Route::get('/', [ConsumoTesteController::class, 'index'])->name('consumo-teste.index');
        Route::get('/create', [ConsumoTesteController::class, 'create'])->name('consumo-teste.create');
        Route::post('/store', [ConsumoTesteController::class, 'store'])->name('consumo-teste.store');
        Route::get('/edit/{id}', [ConsumoTesteController::class, 'edit'])->name('consumo-teste.edit');
        Route::post('/update/{id}', [ConsumoTesteController::class, 'update'])->name('consumo-teste.update');
        Route::get('/show/{id}', [ConsumoTesteController::class, 'show'])->name('consumo-teste.show');
        Route::delete('/delete', [ConsumoTesteController::class, 'delete'])->name('consumo-teste.delete');

    });

    // Rota para exibir a view de leitura do código de barras
    Route::get('/barcode', [BarcodeController::class, 'showBarcodeReader'])->name('leitura');
    Route::get('/leitor-codigo', [BarcodeController::class, 'showBarcodeReader'])->name('leitor-codigo');
    Route::post('/buscar-codigo', [BarcodeController::class, 'buscarCodigo'])->name('buscar-codigo');

    // Rota para receber o código de barras lido
    // Route::post('/barcode', [BarcodeController::class, 'storeBarcode']);

    // Route::get('/barcode/result/{code}', [BarcodeController::class, 'showBarcodeResult'])->name('leitura-show');

    Route::prefix('users')->group(function () {
        Route::get('/', [UserController::class, 'index'])->name('users.index');
        Route::get('/create', [UserController::class, 'create'])->name('users.create');
        Route::post('/store', [UserController::class, 'store'])->name('users.store');
        Route::get('/edit/{id}', [UserController::class, 'edit'])->name('users.edit');
        Route::post('/update/{id}', [UserController::class, 'update'])->name('users.update');
        Route::get('/show/{id}', [UserController::class, 'show'])->name('users.show');
        Route::delete('/delete', [UserController::class, 'delete'])->name('users.delete');

    });

});

// Rota de login
Route::get('login', [LoginController::class, 'showLoginForm'])->name('login');
Route::post('login', [LoginController::class, 'login']);

// Rota de logout
Route::post('logout', [LoginController::class, 'logout'])->name('logout');

// Rotas de reset de senha
Route::get('password/reset', [ForgotPasswordController::class, 'showLinkRequestForm'])->name('password.request');
Route::post('password/email', [ForgotPasswordController::class, 'sendResetLinkEmail'])->name('password.email');
Route::get('password/reset/{token}', [ResetPasswordController::class, 'showResetForm'])->name('password.reset');
Route::post('password/reset', [ResetPasswordController::class, 'reset'])->name('password.update');
